==> mingw-w64-qucs-s-24.4.1-1.src.tar.zst: qucs-s-24.4.1/qucs/spicecomponents/spicelibcomp.h <==
/***************************************************************************
                               spicelibcomp.h
                              --------------
    begin                : Tue Mar 08 2016
    copyright            : (C) 2016 by Vadim Kuznetsov
    email                : ra3xdh@gmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SPICELIBCOMP_H
#define SPICELIBCOMP_H

#include "components/component.h"


class SpiceLibComp : public MultiViewComponent  {
public:
  SpiceLibComp();
 ~SpiceLibComp() {};
  Component* newOne();
  static Element* info(QString&, char* &, bool getNewOne=false);
  QString getSpiceLibrary();

protected:
  QString spice_netlist(bool isXyce);
  void createSymbol();
  void remakeSymbol(int No, QStringList &pin_names);
  int  loadSymbol(const QString&);
private:
  void removeUnusedPorts();
};

#endif

==> mingw-w64-qucs-s-25.1.0-1.src.tar.zst: qucs-s-25.1.0/qucs/spicecomponents/spicelibcomp.h <==
/***************************************************************************
                               spicelibcomp.h
                              --------------
    begin                : Tue Mar 08 2016
    copyright            : (C) 2016 by Vadim Kuznetsov
    email                : ra3xdh@gmail.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef SPICELIBCOMP_H
#define SPICELIBCOMP_H

#include "components/component.h"


class SpiceLibComp : public MultiViewComponent  {
public:
  SpiceLibComp();
 ~SpiceLibComp() {};
  Component* newOne();
  static Element* info(QString&, char* &, bool getNewOne=false);
  QString getSpiceLibrary();
  QStringList getSpiceLibraryFiles();

protected:
  QString spice_netlist(spicecompat::SpiceDialect dialect = spicecompat::SPICEDefault);
  virtual QString cdl_netlist();
  void createSymbol();
  void remakeSymbol(int No, QStringList &pin_names);
  int  loadSymbol(const QString&);

private:
  void removeUnusedPorts();
};

#endif
